# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import pennprov
from pennprov.models.integer_field_model import IntegerFieldModel  # noqa: E501
from pennprov.rest import ApiException


class TestIntegerFieldModel(unittest.TestCase):
    """IntegerFieldModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIntegerFieldModel(self):
        """Test IntegerFieldModel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pennprov.models.integer_field_model.IntegerFieldModel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
