# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import pennprov
from pennprov.api.provenance_api import ProvenanceApi  # noqa: E501
from pennprov.rest import ApiException


class TestProvenanceApi(unittest.TestCase):
    """ProvenanceApi unit test stubs"""

    def setUp(self):
        self.api = pennprov.api.provenance_api.ProvenanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_connected_from(self):
        """Test case for get_connected_from

        Get the outgoing neighbors of the given prov token  # noqa: E501
        """
        pass

    def test_get_connected_to(self):
        """Test case for get_connected_to

        Get the incoming neighbors of the given prov token  # noqa: E501
        """
        pass

    def test_get_edges_from(self):
        """Test case for get_edges_from

        Get the outgoing edges of the given prov token  # noqa: E501
        """
        pass

    def test_get_edges_to(self):
        """Test case for get_edges_to

        Get the incoming edges of the given prov token  # noqa: E501
        """
        pass

    def test_get_provenance_data(self):
        """Test case for get_provenance_data

        Get the tuple associated with a provenance token  # noqa: E501
        """
        pass

    def test_get_provenance_location(self):
        """Test case for get_provenance_location

        Get the location of a provenance token  # noqa: E501
        """
        pass

    def test_get_provenance_nodes(self):
        """Test case for get_provenance_nodes

        Get the provenance graph's nodes  # noqa: E501
        """
        pass

    def test_store_provenance_link(self):
        """Test case for store_provenance_link

        Store a provenance link between tokens  # noqa: E501
        """
        pass

    def test_store_provenance_node(self):
        """Test case for store_provenance_node

        Store a provenance token with its location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
